snapshot_instance
:   The name of the VM or compute instance where the storage volumes are
    attached. Required when the `snapshot` value is specified for
    `backup_method`.

    Scope: Server/Model.
